==> MLML2R_0.2.0.tar.gz: MLML2R/R/data.R <==
#' Methylated counts from BS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"MethylatedBS_sim"

#' Methylated counts from oxBS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"MethylatedOxBS_sim"

#' Methylated counts from TAB
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"MethylatedTAB_sim"

#' Unmethylated counts from oxBS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"UnMethylatedOxBS_sim"

#' Unmethylated counts from BS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"UnMethylatedBS_sim"

#' Unmethylated counts from TAB
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"UnMethylatedTAB_sim"

==> MLML2R_0.3.3.tar.gz: MLML2R/R/data.R <==
#' C (unconverted) counts from BS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"C_BS_sim"

#' C (unconverted) counts from oxBS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"C_OxBS_sim"

#' C (unconverted) counts from TAB
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"C_TAB_sim"

#' T (converted) counts from oxBS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"T_OxBS_sim"

#' T (converted) counts from BS
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"T_BS_sim"

#' T (converted) counts from TAB
#'
#' A matrix of simulated counts corresponding to 100 CpGs and 2 samples.
#' True proportions of methylation, hydroxymethylation and unmethylated
#' used in the simulation are .3, .2, and .5, respectively.
#'
#' @format
#'
#' 100 x 2 matrix (CpGs in the rows and  Samples in the columns).
#'
"T_TAB_sim"
